library("DynamicGP")
library("serialization")
library("simfuncs")
load("dataset.RData")
set.seed(35)

numrep <- 50
ends <- c(30,50)
sfrac <- c(.25,.5)
nends <- length(ends)
nsfrac <- length(sfrac)
lgavemse <- lgmedmse <- lgavescore <- lgmedscore <- lgtime <- matrix(NA,nrow=numrep,ncol=nends*nsfrac)
lnavemse <- lnmedmse <- lnavescore <- lnmedscore <- lntime <- matrix(NA,nrow=numrep,ncol=nends)
items <- ls(pattern="ave|med|time")
idims <- lapply(items,function(x)dim(get(x)))
timepoints <- seq(0.3,60,0.3)
serfname <- "localsvdgp.txt"
fcon <- writeheader(serfname,items,idims)
gs <- sqrt(.Machine$double.eps)
for(i in 1:numrep)
{
    design <- trainlist[[i]]
    test <- testlist[[i]]
    resp <- apply(design,1,environ,timepoints)
    tres <- apply(test,1,environ,timepoints)
    m <- 1
    for(j in 1:nends)
    {
        tmnn <- system.time(retnn <- try(knnsvdGP(design,resp,test,ends[j],frac=.95,centralize=TRUE,gstart=gs,nthread=8)))
        if(!inherits(retnn,"try-error"))
        {
            msen <- lscalemse(tres,retnn$pmean)
            lnavemse[i,j] <- mean(msen)
            lnmedmse[i,j] <- median(msen)
            scoren <- scoring(tres,retnn$pmean,sqrt(retnn$ps2))
            lnavescore[i,j] <- mean(scoren)
            lnmedscore[i,j] <- median(scoren)
            lntime[i,j] <- tmnn[3]
            ## write to txt file
            writedata(fcon,"lnavemse",c(i,j),lnavemse[i,j])
            writedata(fcon,"lnmedmse",c(i,j),lnmedmse[i,j])
            writedata(fcon,"lnavescore",c(i,j),lnavescore[i,j])
            writedata(fcon,"lnmedscore",c(i,j),lnmedscore[i,j])
            writedata(fcon,"lntime",c(i,j),lntime[i,j])
            flush(fcon)
        }
        gc(reset=TRUE)
        for(k in 1:nsfrac)
        {
            n0 <- ceiling(ends[j]*sfrac[k])
            tmgg <- system.time(retgg <- try(lasvdGP(design,resp,test,n0,ends[j],every=5,frac=.95,centralize=TRUE,gstart=gs,nthread=8)))
            if(!inherits(retgg,"try-error"))
            {
                mseg <- lscalemse(tres,retgg$pmean)
                lgavemse[i,m] <- mean(mseg)
                lgmedmse[i,m] <- median(mseg)
                scoreg <- scoring(tres,retgg$pmean,sqrt(retgg$ps2))
                lgavescore[i,m] <- mean(scoreg)
                lgmedscore[i,m] <- median(scoreg)
                lgtime[i,m] <- tmgg[3]
                ## write to txt file
                writedata(fcon,"lgavemse",c(i,m),lgavemse[i,m])
                writedata(fcon,"lgmedmse",c(i,m),lgmedmse[i,m])
                writedata(fcon,"lgavescore",c(i,m),lgavescore[i,m])
                writedata(fcon,"lgmedscore",c(i,m),lgmedscore[i,m])
                writedata(fcon,"lgtime",c(i,m),lgtime[i,m])
                flush(fcon)
            }
            m <- m+1
            gc(reset=TRUE)
        }
    }
    cat("repetition ",i," complete!\n")
}
close(fcon)
