\name{lscalemse}
\alias{lscalemse}

\title{Evaluating the NMSPE criterion}

\description{
  Evaluate the NMSPE criterion for the matrix of predictive mean of the
  time-series valued responses on a test set.}

\usage{
lscalemse(yreal,ypred)
}
\arguments{
  \item{yreal}{
    an \eqn{L\times M} matrix of real responses on the test set, where
    \eqn{L} is the length of the time series and \eqn{M} is the number
    of input points in the test set.
  }
  \item{ypred}{
    an \eqn{L\times M} matrix of predictive mean for the responses on
    the test set. The size of \code{ypred} must be equal to that of
    \code{yreal}.
  }
}
\value{
  It returns a vector of length \eqn{M} contains the values of NMSPE at
  each test point, where \eqn{M} is the number of test points.
}
\author{Ru Zhang \email{14rz14@queensu.ca}}
\examples{
library("lhs")
library("lasvdgp")
library("simfuncs")
## generate a design and a test matrix of each 100 points
design <- maximinLHS(100,5)
test <- maximinLHS(100,5)
## specify the timepoints
timepoints <- seq(0.3,60,0.3)
## evaluate the simulator on the design and test set.
resp <- apply(design,1,environ,timepoints)
tres <- apply(test,1,environ,timepoints)
## perform lasvdGP
retg <- lasvdgpWorker(test,design,resp,15,30)
## evaluate the NMSPE
nmse <- lscalemse(tres,retg$pmean)
}
