\name{readdata}
\alias{readdata}

\title{
  Read the Serialized Arrays from a Serialization File
}
\description{
  It read all the written arrays from a serialization file and return a
  list of arrays. The length of the list is the same as the number of
  array names in the header line. The sizes of the arrays in the list
  are specified by the header line.
}
\usage{
readdata(filename)
}
\arguments{
  \item{filename}{
    a string of the name of the serialization file to be read.
  }
}
\value{
  \item{lst}{
    a list of arrays written in the serialization file. The names and
    the sizes of the arrays are determined by the header line. The
    \code{readdata} function will fill \code{NA} for the positions not
    written in the serialization file.
  }
}
\author{Ru Zhang \email{14rz14@queensu.ca}}
\examples{
library("serialization")
## we intend to write two matrices into the serialization file
mats <- c("mat1","mat2")
## dim(mat1)=c(2,3), dim(mat2)=c(4,2)
dims <- list(c(2,3),c(4,2))
fcon <- writeheader("mats.txt",mats,dims)
flush(fcon)
## mats.txt has been created the first line is
## headerline:mat1,2,3;mat2,4,2;

## write data
writedata(fcon,"mat1",c(1,1),0)
writedata(fcon,"mat1",c(1,2),1)
writedata(fcon,"mat2",c(1,1),2)
## close connection
close(fcon)
## read the file and obtain the matrices
lst <- readdata("mats.txt")
## show the names of the loaded matrices
names(lst)
print(lst)
}
