writeheader <- function(filename,items,dims)
{
    itemslen <- length(items)
    dimslen <- length(dims)
    if(dimslen != itemslen && dimslen != 1)
        stop("incorrect specification of dims!")
    fcon <- file(filename,open="w")
    writeLines("headerline:",con=fcon,sep="")
    for(i in 1:itemslen)
    {
        cdim <- dims[[min(dimslen,i)]]
        text <- paste(items[i],paste(cdim,collapse=","),sep=",")
        writeLines(text,fcon,sep=";")
    }
    writeLines("",fcon)
    return(fcon)
}
## add header line for the existing file
getheader <- function(items,dims)
{
    itemslen <- length(items)
    dimslen <- length(dims)
    if(dimslen != itemslen && dimslen != 1)
        stop("incorrect specification of dims!")
    header <- "headerline:"
    for(i in 1:itemslen)
    {
        cdim <- dims[[min(dimslen,i)]]
        lineadd <- paste(items[i],paste(cdim,collapse=","),sep=",")
        header <- paste(header,lineadd,";",sep="")
    }
    return(header)
}
## note that this function are not responsible to close the connection
writedata <- function(fcon,itemname,dim,value)
{
    strdim <- paste(dim,collapse=",")
    item <- paste(itemname,strdim,sep=",")
    line <- paste(item,value,sep=":")
    writeLines(line,fcon)
}
parseheader <- function(headerline)
{
    headerline <- gsub(" ","",headerline)
    spwd <- strsplit(headerline,":")
    header <- spwd[[1]][1]
    if(header != "headerline")
        stop("incorrect header!")
    items <- spwd[[1]][2]
    itemsspec <- strsplit(items,";")[[1]]
    ispeclst <- strsplit(itemsspec,",")
    inames <- sapply(ispeclst,`[`,1)
    idims <- lapply(ispeclst,`[`,-1)
    idims <- lapply(idims,as.numeric)
    names(idims) <- inames
    return(list(inames=inames,idims=idims))
}
mergeheaders <- function(oldheader,newheader,mergedim)
{
    for(name in newheader$inames)
    {
        if(name %in% oldheader$inames)
        {
            num <- oldheader$idims[[name]][mergedim]
            oldheader$cnum[name] <- num
            num <- num + newheader$idims[[name]][mergedim]
            oldheader$idims[[name]][mergedim] <- num
        }
        else
        {
            oldheader$inames <- c(oldheader$inames,name)
            oldheader$idims[[name]] <- newheader$idims[[name]]
            oldheader$cnum[name] <- 0
        }
    }
    return(oldheader)
}
readdata <- function(filename)
{
    fcon <- file(filename,open="r")
    ## skip blank lines in the begining of the file
    while((wd <- readLines(fcon,1)) == ""){}
    ## parse the header
    header <- parseheader(wd)
    itemlist <- lapply(header$idims,function(d)array(dim=d))
    names(itemlist) <- header$inames
    ## read data
    while(length(wd <- readLines(fcon,1)) != 0)
    {
        if(wd == "") next
        citem <- strsplit(wd,":")[[1]]
        item <- citem[1]
        value <- as.numeric(citem[2])
        ispec <- strsplit(item,",")[[1]]
        name <- ispec[1]
        cdim <- header$idims[[name]]
        pos <- as.numeric(ispec[-1])
        if(length(pos) == 1)
        {
            itemlist[[name]][pos] <- value
            next
        }
        offset <- sum((pos[-1]-1)*cumprod(cdim[-length(cdim)]))+pos[1]
        itemlist[[name]][offset] <- value
    }
    close(fcon)
    return(itemlist)
}
## assume merge all the items with the same margin
## note that for the first file it is inefficient
mergeseries <- function(ifilelist,mergedims,ofile,tfile="tmp.txt")
{
    tfcon <- file(tfile,"w")
    oheader <- list(inames=c(),idims=list(),cnum=c())
    for(fname in ifilelist)
    {
        fcon <- file(fname,open="r")
        while((wd <- readLines(fcon,1)) == ""){}
        iheader <- parseheader(wd)
        oheader <- mergeheaders(oheader,iheader,mergedims)
        while(length(wd <- readLines(fcon,1)) != 0)
        {
            citem <- strsplit(wd,":")[[1]]
            item <- citem[1]
            ispec <- strsplit(item,",")[[1]]
            name <- ispec[1]
            cnum <- oheader$cnum[name]
            if(cnum==0)
            {
                writeLines(wd,tfcon)
                next
            }
            cdim <- as.numeric(ispec[-1])
            cdim[mergedims] <- cdim[mergedims]+cnum
            value <- as.numeric(citem[2])
            writedata(tfcon,name,cdim,value)
        }
        close(fcon)
    }
    close(tfcon)
    strheader <- getheader(oheader$inames,oheader$idims)
    tfcon <- file(tfile,open='r')
    ofcon <- file(ofile,"w")
    writeLines(strheader,ofcon)
    while(length(wd <- readLines(tfcon,1)) != 0)
        writeLines(wd,ofcon)
    close(ofcon)
    close(tfcon)
    file.remove(tfile)
}
writebatch <- function(fcon,itemname,indices,values)
{
    dlen <- sapply(indices,length)
    tlen <- prod(dlen)
    if(length(values) != tlen)
        stop("inconsistent length of indices and values!")
    for(i in 1:tlen)
    {
        idx <- arrayInd(i,dlen)
        ridx <- mapply(`[`,indices,idx)
        writedata(fcon,itemname,ridx,values[i])
    }
}
