\name{writedata}
\alias{writedata}
\title{
  Write One Entry of an Array into the Serialization File
}
\description{
  This function write one entry of one array to the serialization file,
  this entry takes up one line in the file. The format is

  arrname,dim1,dim2:data

  where arrname is the name of the array to be serialized, dim1 and dim2
  are the positions of the data in terms of the first and the second
  dimension of the array, data is value of this entry.
}
\usage{
writedata(fcon,itemname,dim,value)
}
\arguments{
  \item{fcon}{
    the file connection object of the serialization file created by the
    \code{writeheader} function.
  }
  \item{itemname}{
    a string of the name of the array (vector or matrix) to be written.
  }
  \item{dim}{
    a numerical vector indicates the position of the entry to be written.
  }
  \item{value}{
    the value of the entry to be written, currently only support
    numerical value.
  }
}
\author{Ru Zhang \email{14rz14@queensu.ca}}
\examples{
library("serialization")
## we intend to write two matrices into the serialization file
mats <- c("mat1","mat2")
## dim(mat1)=c(2,3), dim(mat2)=c(4,2)
dims <- list(c(2,3),c(4,2))
fcon <- writeheader("mats.txt",mats,dims)
flush(fcon)
## mats.txt has been created the first line is
## headerline:mat1,2,3;mat2,4,2;

## write data
writedata(fcon,"mat1",c(1,1),0)
writedata(fcon,"mat1",c(1,2),1)
writedata(fcon,"mat2",c(1,1),2)
## close connection
close(fcon)
## the mats.txt becomes
## headerline:mat1,2,3;mat2,4,2;
## mat1,1,1:0
## mat1,1,2:1
## mat2,1,1:2
}
