\name{writeheader}
\alias{writeheader}

\title{
  Write a Header Line to the Serialization File
}
\description{
  Write a header line to the serialization file. The header line
  indicate the name of the arrays written into
  this file. The format is

  headerline:arr1,row1,col1;arr2,row2,col2;

  where arr1 is the name of the first array, row1 and col1 are the
  numbers of rows and columns of arr1. information for different arrays
  are separated by semicolon.
}
\usage{
writeheader(filename,items,dims)
}
\arguments{
  \item{filename}{
    a string of the name of the file for serialization.}
  \item{items}{
    a vector of strings, each string is a name of an array to be saved
    in the serialization file.
  }
  \item{dims}{
    a list of vectors, each vector indicates the size of an array to be
    saved in the serialization file. The length
    of \code{dims} must be equal to the length of \code{items} or
    1. When \code{dims=1}, all the arrays are the same size.}
}
\value{
  \item{fcon} {a connect object to the serialization file.}
}
\author{Ru Zhang \email{14rz14@queensu.ca}}

\examples{
library("serialization")
## we intend to write two matrices into the serialization file
mats <- c("mat1","mat2")
## dim(mat1)=c(2,3), dim(mat2)=c(4,2)
dims <- list(c(2,3),c(4,2))
fcon <- writeheader("mats.txt",mats,dims)
flush(fcon)
## mats.txt has been created the first line is
## headerline:mat1,2,3;mat2,4,2;

## write data
writedata(fcon,"mat1",c(1,1),0)
writedata(fcon,"mat1",c(1,2),1)
writedata(fcon,"mat2",c(1,1),2)
## close connection
close(fcon)
## the mats.txt becomes
## headerline:mat1,2,3;mat2,4,2;
## mat1,1,1:0
## mat1,1,2:1
## mat2,1,1:2
}
\keyword{serialization}
\keyword{write files}

